//
//  MapViewController.m
//  BostonCambridgeRecordStores
//
//  Created by Gloria Hedlund on 4/7/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import <MapKit/MapKit.h>
#import <MediaPlayer/MediaPlayer.h>
#import "MapViewController.h"
#import "RecordStoreAnnotation.h"

@interface MapViewController () <MKMapViewDelegate>

@property (weak, nonatomic) IBOutlet MKMapView *mapView;
@property (nonatomic, strong) MPMoviePlayerController *moviePlayer;
@property (nonatomic, strong) CLLocation *myLocation;

@end

@implementation MapViewController

@synthesize myLocation = _myLocation;
@synthesize mapView = _mapView;
@synthesize annotations = _annotations;
@synthesize moviePlayer = _moviePlayer;

// this ensures that the view and the model are always in sync
// update the mapView whenever something changes in either the 
// model or the view
- (void)updateMapView
{
    if (self.mapView.annotations)
        [self.mapView removeAnnotations:self.mapView.annotations];
    if (self.annotations)
        [self.mapView addAnnotations:self.annotations];
}

- (void)setMapView:(MKMapView *)mapView
{
    _mapView = mapView;
    [self updateMapView];
}

- (void)setAnnotations:(NSArray *)annotations
{
    _annotations = annotations;
    [self updateMapView];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    //MAKE YOURSELF THE MAPVIEW DELEGATE
    self.mapView.delegate = self;
    
    // If all you want to do is show the user location, mapkit also has 
    // a very handy BOOL that you just set to true to do this 
    // (and this does NOT require Core Location - bear in mind, this 
    // often does not work in the simulator, unless you set your location
    // in the debugger)
    // self.mapView.showsUserLocation = YES;
    
    // define map span
    MKCoordinateSpan span;
    span.latitudeDelta = 0.028;
    span.longitudeDelta = 0.028;
    
    // Weirdo Records
    CLLocationCoordinate2D weirdo;
    weirdo.latitude = 42.3673363;
    weirdo.longitude = -71.1070387;
    
    // Cheapo Records
    CLLocationCoordinate2D cheapo;
    cheapo.latitude = 42.3644109;
    cheapo.longitude = -71.1021231;
    
    // In Your Ear Records
    CLLocationCoordinate2D inyourear;
    inyourear.latitude = 42.3516151;
    inyourear.longitude = -71.1189894;
    
    // create region, with span and center
    MKCoordinateRegion region;
    region.span = span;
    region.center = weirdo;
    
    // center the map
    [self.mapView setRegion:region animated:YES];
    
    // Create Annotations for the record stores
    RecordStoreAnnotation *annotationW = [[RecordStoreAnnotation alloc] initWithCoordinate:weirdo];
    annotationW.title = @"Weirdo Records";
    annotationW.subtitle = @"844 Mass. Ave, Cambridge";
    annotationW.logo = [UIImage imageNamed:@"weirdo.gif"];
   // This project was too large to upload/ download with the movies attached so I have moved them to the cloud
   // (will be taking them down by beginning of May as well as Amazon will be charging me $$ for S3 service)
   // annotationW.url = [NSURL fileURLWithPath:[[NSBundle mainBundle] pathForResource:@"weirdo" ofType:@"MOV"]];
    annotationW.url = [NSURL URLWithString:@"https://s3.amazonaws.com/RecordStoreMovies/weirdo.MOV"];
    
    RecordStoreAnnotation *annotationC = [[RecordStoreAnnotation alloc] initWithCoordinate:cheapo];
    annotationC.title = @"Cheapo Records";
    annotationC.subtitle = @"538 Mass. Ave, Cambridge";
    annotationC.logo = [UIImage imageNamed:@"cheapo.gif"];
    annotationC.url = [NSURL URLWithString:@"https://s3.amazonaws.com/RecordStoreMovies/cheapo.MOV"];
   // annotationC.url = [NSURL fileURLWithPath:[[NSBundle mainBundle] pathForResource:@"cheapo" ofType:@"MOV"]];
    
    RecordStoreAnnotation *annotationI = [[RecordStoreAnnotation alloc] initWithCoordinate:inyourear];
    annotationI.title = @"In Your Ear Records";
    annotationI.subtitle = @"957 Comm. Ave, Boston";
    annotationI.logo = [UIImage imageNamed:@"inyourear.jpg"];
    annotationI.url = [NSURL URLWithString:@"https://s3.amazonaws.com/RecordStoreMovies/inyourear.MOV"];
   // annotationI.url = [NSURL fileURLWithPath:[[NSBundle mainBundle] pathForResource:@"inyourear" ofType:@"MOV"]];
    
    self.annotations = [[NSArray alloc] initWithObjects:annotationW, annotationC, annotationI, nil];
    
    // add annotation to the map
    [self.mapView addAnnotations:self.annotations];
   
    // add an overlay to the map
    // create a circle around the center of the map (distance in meters)
    MKCircle *circle = [MKCircle circleWithCenterCoordinate:weirdo radius:2000.0];
    [self.mapView addOverlay:circle];
    
}


// CREATING THE ANNOTATION
- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id<MKAnnotation>)annotation
{
    // check and see if there are any markers available in our re-use pool
    MKPinAnnotationView *marker = (MKPinAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:@"Marker"];
    
    // if there are none available, make a new one
    if (!marker) {
        marker = [[MKPinAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"Marker"];
        marker.canShowCallout = YES;
        // add detail disclosure button to view
        marker.rightCalloutAccessoryView = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
        marker.leftCalloutAccessoryView = [[UIImageView alloc] initWithFrame:CGRectMake(0, 0, 33, 33)];
    }
    // yes, if this is a dequeue, we are setting this to annotation twice - no big deal
    marker.annotation = annotation;
    marker.image = [UIImage imageNamed:@"vinyl.jpg"];
    // this is really for the case in which we are using LOTS of pins and we want to make sure we are not getting 
    // a pin back that has an old image in it
    [(UIImageView *)marker.leftCalloutAccessoryView setImage:nil];
    return marker;
}

// SELECTING THE ANNOTATION
// this is where we want to put our image up
- (void)mapView:(MKMapView *)mapView didSelectAnnotationView:(MKAnnotationView *)view
{
    RecordStoreAnnotation *recordStoreannotation = view.annotation;
    [(UIImageView *)view.leftCalloutAccessoryView setImage:recordStoreannotation.logo];
}

// TAPPING THE ANNOTATION CALLOUT VIEW - LETS GO TO THE MOVIES!
- (void)mapView:(MKMapView *)mapView annotationView:(MKAnnotationView *)view calloutAccessoryControlTapped:(UIControl *)control
{
    RecordStoreAnnotation *recordStoreannotation = view.annotation;
    // set up your movie
    self.moviePlayer = [[MPMoviePlayerController alloc] initWithContentURL:recordStoreannotation.url];
    // set a frame or the default is 0 (you will not see anything)
    self.moviePlayer.view.frame = CGRectMake(0, 0, 320, 320);
    [self.view addSubview:self.moviePlayer.view];
    // register for your desired notifications
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(movieOver) name:MPMoviePlayerPlaybackDidFinishNotification object:nil];
    // play the movie
    [self.moviePlayer play];
}

// CREATING THE OVERLAY
-(MKOverlayView *)mapView:(MKMapView *)mapView viewForOverlay:(id)overlay
{
    // overlay is a circle
   if ([overlay isKindOfClass:[MKCircle class]]) {
        // create view for circle
        MKCircleView *circleView = [[MKCircleView alloc] initWithOverlay:overlay];
        
        // set color and width
        circleView.strokeColor = [UIColor blueColor];
        circleView.lineWidth = 5.0;
        
        return circleView;
    }
    return nil;
}

// Callback for MPMoviePlayerPlaybackDidFinishNotification
- (void)movieOver
{
    [self.moviePlayer.view removeFromSuperview];
}

- (void)viewDidUnload
{
    _mapView = nil;
    [self setMapView:nil];
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

@end
