//
//  ViewController.m
//  CoreLocationDemo
//
//  Created by Gloria Hedlund on 4/9/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "ViewController.h"
#import <CoreLocation/CoreLocation.h>

@interface ViewController () <CLLocationManagerDelegate>

@property (nonatomic, strong) CLLocationManager *locationManager;
@property (nonatomic) BOOL canDo;

@end

@implementation ViewController
@synthesize locationButton = _locationButton;
@synthesize latitude = _latitude;
@synthesize longitude = _longitude;
@synthesize locationManager = _locationManager;
@synthesize canDo = _canDo;

- (IBAction)getLocation:(UIButton *)sender {
    
    if (self.canDo == NO) {
        UIAlertView *alert = [[UIAlertView alloc]
                    initWithTitle: @"No Geolocation."
                          message: @"I cannot find out where you are."
                         delegate: nil
                cancelButtonTitle:@"OK"
                otherButtonTitles:nil];
        [alert show];
        return;
    }
    // start the location manager
    [self.locationManager startUpdatingLocation];
    
}

- (void)locationManager:(CLLocationManager *)manager didUpdateToLocation:(CLLocation *)newLocation fromLocation:(CLLocation *)oldLocation
{
    self.latitude.text = [[NSString alloc] initWithFormat:@"%f", newLocation.coordinate.latitude];
    self.longitude.text = [[NSString alloc] initWithFormat:@"%f", newLocation.coordinate.longitude];
    NSLog(@"Just updated my location");
}


- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    self.locationManager = [[CLLocationManager alloc] init];
    self.locationManager.delegate = self;
    self.locationManager.desiredAccuracy = kCLLocationAccuracyBest;
    self.locationManager.distanceFilter = 1000;
    // set this if you want to show the user a "personalized" reason that you are asking for location services to be enabled
    self.locationManager.purpose = @"I would like to get your location so that I can show you your latitude and longitude"; 
    
    self.canDo = NO;
    // Check to see if location services are enabled
    if([CLLocationManager locationServicesEnabled]){
        NSLog(@"Location Services Enabled");
        
        // Switch through the possible location
        // authorization states
        switch([CLLocationManager authorizationStatus]){
                
            case kCLAuthorizationStatusAuthorized:
                NSLog(@"We have access to location services");
                self.canDo = YES;
                break;
            case kCLAuthorizationStatusDenied:
                NSLog(@"Location services denied by user");
                break;
            case kCLAuthorizationStatusRestricted:
                NSLog(@"Parental controls restrict location services");
                break;
            // the iOS simulator is bizarre - if you refuse location services
            // its is set to this instead of kCLAuthorizationStatusDenied
            case kCLAuthorizationStatusNotDetermined:
                NSLog(@"Unable to determine, possibly not available");
                self.canDo = YES;
        }
    }
    else{
        // locationServicesEnabled was set to NO
        NSLog(@"Location Services Are Disabled");
    }

}

- (void)viewDidUnload
{
    [self setLocationButton:nil];
    [self setLatitude:nil];
    [self setLongitude:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

@end
